@@ -22,7 +22,7 @@ class PushButtonDraggable(QtWidgets.QPushButton, MenuInstance, Attributes, RichT
 
 		self.setStyleSheet('''
 			QPushButton {
-				border: 1px solid transparent;
+				border: 1px solid black;
 				background-color: rgba(127,127,127,2);
 			}
 
@@ -137,6 +137,7 @@ class PushButtonDraggable(QtWidgets.QPushButton, MenuInstance, Attributes, RichT
 
 		QtWidgets.QPushButton.hideEvent(self, event)
 
+# -----------------------------------------------------------------------------
 
 
 
@@ -145,6 +146,9 @@ class PushButtonDraggable(QtWidgets.QPushButton, MenuInstance, Attributes, RichT
 
 
 
+
+# -----------------------------------------------------------------------------
+
 if __name__ == "__main__":
 	import sys
 	app = QtWidgets.QApplication.instance() or QtWidgets.QApplication(sys.argv) #return the existing QApplication object, or create a new one if none exists.
@@ -154,8 +158,6 @@ if __name__ == "__main__":
 
 	sys.exit(app.exec_())
 
-
-
 # -----------------------------------------------------------------------------
 # Notes
 # -----------------------------------------------------------------------------
